extern crate glib;
extern crate glib_sys;

extern crate libc;
extern crate bitflags;

#[macro_use]
mod macros;

pub mod auto;
pub use auto::*;

